@@ -47,6 +47,7 @@ use std::error::Error as StdError;
 use std::ffi::{OsStr, OsString};
 use std::io::{self, BufRead, IsTerminal, Write};
 use std::iter;
+use std::panic::PanicHookInfo;
 use std::panic::{self, UnwindSafe};
 use std::path::{Path, PathBuf};
 use std::process::{self, Command, Stdio};
@@ -55,9 +56,6 @@ use std::str;
 use std::thread::Result as ThreadResult;
 use termcolor::{Color::Green, ColorChoice, ColorSpec, StandardStream, WriteColor};
 
-#[allow(deprecated)] // https://github.com/dtolnay/cargo-expand/issues/229
-use std::panic::PanicInfo;
-
 cargo_subcommand_metadata::description!("Show result of macro expansion");
 
 fn main() {
@@ -647,8 +645,7 @@ fn ignore_panic<F, T>(f: F) -> ThreadResult<T>
 where
     F: UnwindSafe + FnOnce() -> T,
 {
-    #[allow(deprecated)] // https://github.com/dtolnay/cargo-expand/issues/229
-    type PanicHook = dyn Fn(&PanicInfo) + Sync + Send + 'static;
+    type PanicHook = dyn Fn(&PanicHookInfo) + Sync + Send + 'static;
 
     let null_hook: Box<PanicHook> = Box::new(|_panic_info| { /* ignore */ });
     let sanity_check = ptr::addr_of!(*null_hook);
